==> cscec5b-wzxt-api-3.0.1-20230912.092818-336-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 *
 * @author generator
 *
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long parentId; // parent_id
    private Long tid;
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal nums; // 需求数量
    private java.math.BigDecimal occupyNums; // 占用数量
    private java.math.BigDecimal surplusNums; // 剩余数量
    private java.math.BigDecimal planNumsSum; // 所有需求数量
    private java.math.BigDecimal occupyNumsAll; // 所有占用数量
    private java.math.BigDecimal surplusNumsSum; // 所有剩余数量
    private String memo; // 备注
    private String materialSourceId; // 物资来源主键
    private java.lang.String def1; // 自定义字段
    private java.lang.String def2; // 自定义字段
    private java.lang.String def3; // 自定义字段
    private java.lang.String def4; // 自定义字段
    private java.lang.String def5; // 自定义字段
    private java.math.BigDecimal controlNum; // 总控数量
    private java.math.BigDecimal sumplanNum;  // 累计需求数量
    private java.math.BigDecimal sumorderNum; // 累计采购数量
    private java.math.BigDecimal checkNum; // 累计进场数量
    private java.lang.Integer sourceType; //
    private java.lang.String width; // 宽度
    private java.lang.String height; // 高度
    private java.lang.String length; // 长度
    private java.lang.String surface; // 表面处理
    private java.lang.String color; // 颜色
    private java.lang.String colorNumber; // 色号
    private java.lang.String textureMaterial; // 材质状态
    private java.lang.String wallThickness; // 壁厚要求
    private java.lang.String buildingNumber; // 栋号
    private BigDecimal scale; //控制比例

    public String getWidth() {
        return width;
    }

    public void setWidth(String width) {
        this.width = width;
    }

    public String getHeight() {
        return height;
    }

    public void setHeight(String height) {
        this.height = height;
    }

    public String getLength() {
        return length;
    }

    public void setLength(String length) {
        this.length = length;
    }

    public String getSurface() {
        return surface;
    }

    public void setSurface(String surface) {
        this.surface = surface;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public String getColorNumber() {
        return colorNumber;
    }

    public void setColorNumber(String colorNumber) {
        this.colorNumber = colorNumber;
    }

    public String getTextureMaterial() {
        return textureMaterial;
    }

    public void setTextureMaterial(String textureMaterial) {
        this.textureMaterial = textureMaterial;
    }

    public String getWallThickness() {
        return wallThickness;
    }

    public void setWallThickness(String wallThickness) {
        this.wallThickness = wallThickness;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getSumplanNum() {
        return sumplanNum;
    }

    public void setSumplanNum(BigDecimal sumplanNum) {
        this.sumplanNum = sumplanNum;
    }

    public BigDecimal getSumorderNum() {
        return sumorderNum;
    }

    public void setSumorderNum(BigDecimal sumorderNum) {
        this.sumorderNum = sumorderNum;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    private List<PlanDetailRefVO> planDetail; //

    public List<PlanDetailRefVO> getPlanDetail() {
        return planDetail;
    }

    public void setPlanDetail(List<PlanDetailRefVO> planDetail) {
        this.planDetail = planDetail;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }


    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }

    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }
}

==> cscec5b-wzxt-api-3.0.1-20231129.101151-355-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 *
 * @author generator
 *
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long parentId; // parent_id
    private Long tid;
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal nums; // 需求数量
    private java.math.BigDecimal occupyNums; // 占用数量
    private java.math.BigDecimal surplusNums; // 剩余数量
    private java.math.BigDecimal planNumsSum; // 所有需求数量
    private java.math.BigDecimal occupyNumsAll; // 所有占用数量
    private java.math.BigDecimal surplusNumsSum; // 所有剩余数量
    private String memo; // 备注
    private String materialSourceId; // 物资来源主键
    private java.lang.String def1; // 自定义字段
    private java.lang.String def2; // 自定义字段
    private java.lang.String def3; // 自定义字段
    private java.lang.String def4; // 自定义字段
    private java.lang.String def5; // 自定义字段
    private java.math.BigDecimal controlNum; // 总控数量
    private java.math.BigDecimal sumplanNum;  // 累计需求数量
    private java.math.BigDecimal sumorderNum; // 累计采购数量
    private java.math.BigDecimal checkNum; // 累计进场数量
    private java.lang.Integer sourceType; //
    private java.lang.String width; // 宽度
    private java.lang.String height; // 高度
    private java.lang.String length; // 长度
    private java.lang.String surface; // 表面处理
    private java.lang.String color; // 颜色
    private java.lang.String colorNumber; // 色号
    private java.lang.String textureMaterial; // 材质状态
    private java.lang.String wallThickness; // 壁厚要求
    private java.lang.String buildingNumber; // 栋号
    private BigDecimal scale; //控制比例
    private java.lang.String realUnitId; // 实物单位id
    private java.lang.String realUnitName; // 实物单位名称
    private BigDecimal realTransScale; // 实物单位转换系数
    private BigDecimal realNum; // 实物数量
    private BigDecimal surplusRealNums; // 剩余实物数量
    private java.math.BigDecimal planRealNums; // 计划实物数量
    private BigDecimal occupyRealNums; // 实物占用数量

    public String getWidth() {
        return width;
    }

    public void setWidth(String width) {
        this.width = width;
    }

    public String getHeight() {
        return height;
    }

    public void setHeight(String height) {
        this.height = height;
    }

    public String getLength() {
        return length;
    }

    public void setLength(String length) {
        this.length = length;
    }

    public String getSurface() {
        return surface;
    }

    public void setSurface(String surface) {
        this.surface = surface;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public String getColorNumber() {
        return colorNumber;
    }

    public void setColorNumber(String colorNumber) {
        this.colorNumber = colorNumber;
    }

    public String getTextureMaterial() {
        return textureMaterial;
    }

    public void setTextureMaterial(String textureMaterial) {
        this.textureMaterial = textureMaterial;
    }

    public String getWallThickness() {
        return wallThickness;
    }

    public void setWallThickness(String wallThickness) {
        this.wallThickness = wallThickness;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getSumplanNum() {
        return sumplanNum;
    }

    public void setSumplanNum(BigDecimal sumplanNum) {
        this.sumplanNum = sumplanNum;
    }

    public BigDecimal getSumorderNum() {
        return sumorderNum;
    }

    public void setSumorderNum(BigDecimal sumorderNum) {
        this.sumorderNum = sumorderNum;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    private List<PlanDetailRefVO> planDetail; //

    public List<PlanDetailRefVO> getPlanDetail() {
        return planDetail;
    }

    public void setPlanDetail(List<PlanDetailRefVO> planDetail) {
        this.planDetail = planDetail;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }


    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }

    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public BigDecimal getSurplusRealNums() {
        return surplusRealNums;
    }

    public void setSurplusRealNums(BigDecimal surplusRealNums) {
        this.surplusRealNums = surplusRealNums;
    }

    public BigDecimal getPlanRealNums() {
        return planRealNums;
    }

    public void setPlanRealNums(BigDecimal planRealNums) {
        this.planRealNums = planRealNums;
    }

    public BigDecimal getOccupyRealNums() {
        return occupyRealNums;
    }

    public void setOccupyRealNums(BigDecimal occupyRealNums) {
        this.occupyRealNums = occupyRealNums;
    }
}
